/*
 * Copyright (c) 2014 oracle.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    oracle - initial API and implementation and/or initial documentation
 */

package com.tasktop.c2c.server.profile.domain.em;

import java.util.List;

import com.tasktop.c2c.server.cloud.domain.ProjectServiceStatus;
import com.tasktop.c2c.server.cloud.domain.ServiceType;

/**
 * @author Sundar Sarangan (Oracle Corp.)
 * 
 */
public class OrganizationDiskUsage {

        private String organizationName;
	
        private List<ProjectServiceStatus> projectServiceStatusList;
        private List<ProjectDiskUsage> projectDiskUsageList;
        
        private int currentNumberExecutors;
        private int executorsQuota;
	private long wikiDiskUsageBytes;
	private long taskDiskUsageBytes;
	private long scmDiskUsageBytes;
	private long buildDiskUsageBytes;
	private long mavenDiskUsageBytes;
	private long maxDiskUsageBytes;
        private int memberCount;
        private int projectCount;
        private int projectQuota;
        private long totalDiskUsageBytes = 0;

	public long getWikiDiskUsageBytes() {
		return wikiDiskUsageBytes;
	}

	public void setWikiDiskUsageBytes(long wikiDiskUsageBytes) {
		this.wikiDiskUsageBytes = wikiDiskUsageBytes;
	}

	public long getTaskDiskUsageBytes() {
		return taskDiskUsageBytes;
	}

	public void setTaskDiskUsageBytes(long taskDiskUsageBytes) {
		this.taskDiskUsageBytes = taskDiskUsageBytes;
	}

	public long getScmDiskUsageBytes() {
		return scmDiskUsageBytes;
	}

	public void setScmDiskUsageBytes(long scmDiskUsageBytes) {
		this.scmDiskUsageBytes = scmDiskUsageBytes;
	}

	public long getBuildDiskUsageBytes() {
		return buildDiskUsageBytes;
	}

	public void setBuildDiskUsageBytes(long buildDiskUsageBytes) {
		this.buildDiskUsageBytes = buildDiskUsageBytes;
	}

	public long getMavenDiskUsageBytes() {
		return mavenDiskUsageBytes;
	}

	public void setMavenDiskUsageBytes(long mavenDiskUsageBytes) {
		this.mavenDiskUsageBytes = mavenDiskUsageBytes;
	}

	public void addBytesToServiceDiskUsage(ServiceType serviceType, String bytes) {
		long bytesVal = (bytes == null || bytes.trim().length() == 0) ? 0 : Long.parseLong(bytes);
		switch (serviceType) {
		case WIKI:
			setWikiDiskUsageBytes(wikiDiskUsageBytes + bytesVal);
			break;
		case TASKS:
			setTaskDiskUsageBytes(taskDiskUsageBytes + bytesVal);
			break;
		case SCM:
			setScmDiskUsageBytes(scmDiskUsageBytes + bytesVal);
			break;
		case BUILD:
			setBuildDiskUsageBytes(buildDiskUsageBytes + bytesVal);
			break;
		case MAVEN:
			setMavenDiskUsageBytes(mavenDiskUsageBytes + bytesVal);
			break;
		default:
			break;
		}
                
                totalDiskUsageBytes += bytesVal;
	}

	public long getTotalDiskUsageBytes() {
		return wikiDiskUsageBytes + taskDiskUsageBytes + scmDiskUsageBytes + buildDiskUsageBytes + mavenDiskUsageBytes;
                //return totalDiskUsageBytes;
	}

	public void setDiskUsageQuota(long maxDiskUsageBytes) {
		this.maxDiskUsageBytes = maxDiskUsageBytes;
	}

	public long getDiskUsageQuota() {
		return maxDiskUsageBytes;
	}

	public List<ProjectServiceStatus> getProjectServiceStatusList() {
		// guarantee that the metrics always have the expected keys
		for (ProjectServiceStatus pss : projectServiceStatusList) {
			if (!pss.getMetrics().containsKey(ProjectServiceStatus.DISK_USAGE_METRICS_KEY)) {
				pss.getMetrics().put(ProjectServiceStatus.DISK_USAGE_METRICS_KEY, "");
			}
			if (!pss.getMetrics().containsKey(ProjectServiceStatus.DISK_USAGE_HR_METRICS_KEY)) {
				pss.getMetrics().put(ProjectServiceStatus.DISK_USAGE_HR_METRICS_KEY, "");
			}
		}

		return projectServiceStatusList;
	}

	public void setProjectServiceStatusList(List<ProjectServiceStatus> projectServiceStatusList) {
		this.projectServiceStatusList = projectServiceStatusList;
	}

        /**
         * @return the projectDiskUsageList
         */
        public List<ProjectDiskUsage> getProjectDiskUsageList() {
            return projectDiskUsageList;
        }

        /**
         * @param projectDiskUsageList the projectDiskUsageList to set
         */
        public void setProjectDiskUsageList(List<ProjectDiskUsage> projectDiskUsageList) {
            this.projectDiskUsageList = projectDiskUsageList;
        }

    /**
     * @return the memberCount
     */
    public int getMemberCount() {
        return memberCount;
    }

    /**
     * @param memberCount the memberCount to set
     */
    public void setMemberCount(int memberCount) {
        this.memberCount = memberCount;
    }

    /**
     * @return the projectCount
     */
    public int getProjectCount() {
        return projectCount;
    }

    /**
     * @param projectCount the projectCount to set
     */
    public void setProjectCount(int projectCount) {
        this.projectCount = projectCount;
    }

    /**
     * @return the organizationName
     */
    public String getOrganizationName() {
        return organizationName;
    }

    /**
     * @param organizationName the organizationName to set
     */
    public void setOrganizationName(String organizationName) {
        this.organizationName = organizationName;
    }

    public String getDiskUsagePercentage() {
        String retVal = "--";
        if(getDiskUsageQuota() > 0) {
            retVal = String.valueOf((getTotalDiskUsageBytes() * 100) / getDiskUsageQuota());
        }
        
        return retVal;
    }

    /**
     * @return the currentNumberExecutors
     */
    public int getCurrentNumberExecutors() {
        return currentNumberExecutors;
    }

    /**
     * @param currentNumberExecutors the currentNumberExecutors to set
     */
    public void setCurrentNumberExecutors(int currentNumberExecutors) {
        this.currentNumberExecutors = currentNumberExecutors;
    }

    /**
     * @return the executorsQuota
     */
    public int getExecutorsQuota() {
        return executorsQuota;
    }

    /**
     * @param executorsQuota the executorsQuota to set
     */
    public void setExecutorsQuota(int executorsQuota) {
        this.executorsQuota = executorsQuota;
    }

    /**
     * @return the projectQuota
     */
    public int getProjectQuota() {
        return projectQuota;
    }

    /**
     * @param projectQuota the projectQuota to set
     */
    public void setProjectQuota(int projectQuota) {
        this.projectQuota = projectQuota;
    }
}