/*
 * Copyright (c) 2014 susaran.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    susaran - initial API and implementation and/or initial documentation
 */

package com.tasktop.c2c.server.profile.domain.em;

import com.tasktop.c2c.server.cloud.domain.ProjectServiceStatus;
import com.tasktop.c2c.server.cloud.domain.ServiceType;
import com.tasktop.c2c.server.profile.domain.project.Profile;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author susaran
 */
public class ProjectDiskUsage {    
    private String projectIdentifier;
    private long wikiDiskUsageBytes;
    private long taskDiskUsageBytes;
    private long scmDiskUsageBytes;
    private long buildDiskUsageBytes;
    private long mavenDiskUsageBytes;
    private long maxDiskUsageBytes;
    private List<ProjectServiceStatus> projectServiceStatusList;
    private List<Profile> profiles;
    private int memberCount;
    private String percentOrgDiskUsage;
    private String jobsBuilding;
    private long organizationDiskUsageQuota;
    private String projectName;

    /**
     * @return the projectIdentifier
     */
    public String getProjectIdentifier() {
        return projectIdentifier;
    }

    /**
     * @param projectIdentifier the projectIdentifier to set
     */
    public void setProjectIdentifier(String projectIdentifier) {
        this.projectIdentifier = projectIdentifier;
    }

    /**
     * @return the wikiDiskUsageBytes
     */
    public long getWikiDiskUsageBytes() {
        return wikiDiskUsageBytes;
    }

    /**
     * @param wikiDiskUsageBytes the wikiDiskUsageBytes to set
     */
    public void setWikiDiskUsageBytes(long wikiDiskUsageBytes) {
        this.wikiDiskUsageBytes = wikiDiskUsageBytes;
    }

    /**
     * @return the taskDiskUsageBytes
     */
    public long getTaskDiskUsageBytes() {
        return taskDiskUsageBytes;
    }

    /**
     * @param taskDiskUsageBytes the taskDiskUsageBytes to set
     */
    public void setTaskDiskUsageBytes(long taskDiskUsageBytes) {
        this.taskDiskUsageBytes = taskDiskUsageBytes;
    }

    /**
     * @return the scmDiskUsageBytes
     */
    public long getScmDiskUsageBytes() {
        return scmDiskUsageBytes;
    }

    /**
     * @param scmDiskUsageBytes the scmDiskUsageBytes to set
     */
    public void setScmDiskUsageBytes(long scmDiskUsageBytes) {
        this.scmDiskUsageBytes = scmDiskUsageBytes;
    }

    /**
     * @return the buildDiskUsageBytes
     */
    public long getBuildDiskUsageBytes() {
        return buildDiskUsageBytes;
    }

    /**
     * @param buildDiskUsageBytes the buildDiskUsageBytes to set
     */
    public void setBuildDiskUsageBytes(long buildDiskUsageBytes) {
        this.buildDiskUsageBytes = buildDiskUsageBytes;
    }

    /**
     * @return the mavenDiskUsageBytes
     */
    public long getMavenDiskUsageBytes() {
        return mavenDiskUsageBytes;
    }

    /**
     * @param mavenDiskUsageBytes the mavenDiskUsageBytes to set
     */
    public void setMavenDiskUsageBytes(long mavenDiskUsageBytes) {
        this.mavenDiskUsageBytes = mavenDiskUsageBytes;
    }

    /**
     * @return the maxDiskUsageBytes
     */
    public long getMaxDiskUsageBytes() {
        return maxDiskUsageBytes;
    }

    /**
     * @param maxDiskUsageBytes the maxDiskUsageBytes to set
     */
    public void setMaxDiskUsageBytes(long maxDiskUsageBytes) {
        this.maxDiskUsageBytes = maxDiskUsageBytes;
    }
    
    public void addBytesToServiceDiskUsage(ServiceType serviceType, String bytes) {
		long bytesVal = (bytes == null || bytes.trim().length() == 0) ? 0 : Long.parseLong(bytes);
		switch (serviceType) {
		case WIKI:
			setWikiDiskUsageBytes(wikiDiskUsageBytes + bytesVal);
			break;
		case TASKS:
			setTaskDiskUsageBytes(taskDiskUsageBytes + bytesVal);
			break;
		case SCM:
			setScmDiskUsageBytes(scmDiskUsageBytes + bytesVal);
			break;
		case BUILD:
			setBuildDiskUsageBytes(buildDiskUsageBytes + bytesVal);
			break;
		case MAVEN:
			setMavenDiskUsageBytes(mavenDiskUsageBytes + bytesVal);
			break;
		default:
			break;
		}
	}
    
    public List<ProjectServiceStatus> getProjectServiceStatusList() {
        // guarantee that the metrics always have the expected keys
        if(projectServiceStatusList != null) {
            for (ProjectServiceStatus pss : projectServiceStatusList) {
                    if (!pss.getMetrics().containsKey(ProjectServiceStatus.DISK_USAGE_METRICS_KEY)) {
                            pss.getMetrics().put(ProjectServiceStatus.DISK_USAGE_METRICS_KEY, "");
                    }
                    if (!pss.getMetrics().containsKey(ProjectServiceStatus.DISK_USAGE_HR_METRICS_KEY)) {
                            pss.getMetrics().put(ProjectServiceStatus.DISK_USAGE_HR_METRICS_KEY, "");
                    }
            }
        }

        return projectServiceStatusList;
    }

    public void setProjectServiceStatusList(List<ProjectServiceStatus> projectServiceStatusList) {
        this.projectServiceStatusList = projectServiceStatusList;
    }

    public long getTotalProjectDiskUsageBytes() {
        return wikiDiskUsageBytes + taskDiskUsageBytes + scmDiskUsageBytes + buildDiskUsageBytes + mavenDiskUsageBytes;
    }

    /**
     * @return the projectProfiles
     */
    public List<Profile> getProfiles() {
        if(profiles == null)
            profiles = new ArrayList<Profile>();
        
        return profiles;
    }

    /**
     * @param projectProfiles the projectProfiles to set
     */
    public void setProfiles(List<Profile> projectProfiles) {
        this.profiles = projectProfiles;
    }

    /**
     * @return the memberCount
     */
    public int getMemberCount() {
        return memberCount;
    }

    /**
     * @param memberCount the memberCount to set
     */
    public void setMemberCount(int memberCount) {
        this.memberCount = memberCount;
    }

    /**
     * @return the percentOrgDiskUsage
     */
    public String getPercentOrgDiskUsage() {
        return percentOrgDiskUsage;
    }
    
    public long getGitMavenDiskUsageBytes() {
        return getScmDiskUsageBytes() + getMavenDiskUsageBytes();
    }
    
    public long getTaskWikiDiskUsageBytes() {
        return getTaskDiskUsageBytes() + getWikiDiskUsageBytes();
    }

    /**
     * @param percentOrgDiskUsage the percentOrgDiskUsage to set
     */
    public void setPercentOrgDiskUsage(String percentOrgDiskUsage) {
        this.percentOrgDiskUsage = percentOrgDiskUsage;
    }

    /**
     * @return the jobsBuilding
     */
    public String getJobsBuilding() {
        return jobsBuilding;
    }

    /**
     * @param jobsBuilding the jobsBuilding to set
     */
    public void setJobsBuilding(String jobsBuilding) {
        this.jobsBuilding = jobsBuilding;
    }

    /**
     * @return the organizationDiskUsageQuota
     */
    public long getOrganizationDiskUsageQuota() {
        return organizationDiskUsageQuota;
    }

    /**
     * @param organizationDiskUsageQuota the organizationDiskUsageQuota to set
     */
    public void setOrganizationDiskUsageQuota(long organizationDiskUsageQuota) {
        this.organizationDiskUsageQuota = organizationDiskUsageQuota;
    }

    /**
     * @return the projectName
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * @param projectName the projectName to set
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
